Index: trunk/MagicSoft/Mars/Makefile.conf.general
===================================================================
--- trunk/MagicSoft/Mars/Makefile.conf.general	(revision 2505)
+++ trunk/MagicSoft/Mars/Makefile.conf.general	(revision 2506)
@@ -18,5 +18,5 @@
 #   export MARSLIBS="-lX11 -lXpm -L/usr/X11R6/lib"
 #
-DEFINES	  = -DMARSVER=\"\<cvs\>\" -D__MARS__ -DROOTVER=\"$(ROOTVER)\" $(ARCHDEF) $(MARSDEFINES)
+DEFINES	  = -DMARSVER=\"0.8.2\" -D__MARS__ -DROOTVER=\"$(ROOTVER)\" $(ARCHDEF) $(MARSDEFINES)
 
 CXXFLAGS  = $(ROOTCFLAGS) $(INCLUDES) $(OPTIM) $(DEBUG) $(DEFINES)
Index: trunk/MagicSoft/Mars/mbase/Makefile
===================================================================
--- trunk/MagicSoft/Mars/mbase/Makefile	(revision 2505)
+++ trunk/MagicSoft/Mars/mbase/Makefile	(revision 2506)
@@ -21,5 +21,6 @@
 
 INCLUDES = -I. -I../mfileio -I../mfilter
-# MRead (MEvtLoop), MF (MContinue)
+# mfileio:  MRead (MEvtLoop)
+# mfilter:  MF (MContinue)
 
 # @code 
@@ -50,7 +51,8 @@
            MReadSocket.cc \
            MDirIter.cc \
+           MGGroupFrame.cc \
            MGList.cc \
            MGTask.cc \
-           MGGroupFrame.cc \
+           MStatusDisplay.cc \
 	   MArray.cc \
 	   MArrayB.cc \
Index: trunk/MagicSoft/Mars/mmain/Makefile
===================================================================
--- trunk/MagicSoft/Mars/mmain/Makefile	(revision 2505)
+++ trunk/MagicSoft/Mars/mmain/Makefile	(revision 2506)
@@ -22,7 +22,7 @@
 #  connect the include files defined in the config.mk file
 #
-INCLUDES = -I. -I../mbase -I../manalysis -I../mdatacheck -I../meventdisp \
+INCLUDES = -I. -I../mbase -I../manalysis -I../mdatacheck -I../mraw       \
 	   -I../mgui -I../mgeom -I../mhist -I../mmontecarlo -I../mfileio \
-           -I../mimage -I../mhistmc -I../mraw
+           -I../mimage -I../mhistmc -I../mgbase
 
 #------------------------------------------------------------------------------
@@ -35,6 +35,6 @@
            MAnalysis.cc \
 	   MMonteCarlo.cc \
+           MGDisplayAdc.cc \
 	   MEventDisplay.cc \
-           MGDisplayAdc.cc \
            MCameraDisplay.cc
 
@@ -54,3 +54,2 @@
 
 # @endcode
-
Index: trunk/MagicSoft/Mars/status.cc
===================================================================
--- trunk/MagicSoft/Mars/status.cc	(revision 2505)
+++ trunk/MagicSoft/Mars/status.cc	(revision 2506)
@@ -27,10 +27,13 @@
 //  Status - Example how to use the MStatusDisplay
 //
 //  Use a camera file as input
 //
 /////////////////////////////////////////////////////////////////////////////
 
 #include "MStatusDisplay.h"
+#include "MArray.h"
 #include "MLog.h"
+#include "MArgs.h"
+#include "MLogManip.h"
 #include "MParList.h"
 #include "MTaskList.h"
@@ -39,4 +42,5 @@
 #include "MMcPedestalCopy.h"
 #include "MMcPedestalNSBAdd.h"
+#include "MCerPhotCalc.h"
 #include "MCerPhotAnal2.h"
 //#include "MBlindPixelCalc.h"
@@ -51,10 +55,85 @@
 
 #include <TApplication.h>
+#include <TSystem.h>
+
+static void StartUpMessage()
+{
+    gLog << all << endl;
+
+    //                1         2         3         4         5
+    //       12345678901234567890123456789012345678901234567890
+    gLog << "==================================================" << endl;
+    gLog << "               status - MARS V" << MARSVER          << endl;
+    gLog << "     MARS - Merging and Preprocessing Program"      << endl;
+    gLog << "            Compiled on <" << __DATE__ << ">"       << endl;
+    gLog << "               Using ROOT v" << ROOTVER             << endl;
+    gLog << "   PROGRAM IS PRELIMINARY - FOR TEST CASES ONLY"    << endl;
+    gLog << "==================================================" << endl;
+    gLog << endl;
+}
+
+static void Usage()
+{
+    gLog << all << endl;
+    gLog << "Sorry the usage is:" << endl;
+    gLog << "   status [-a0] [-vn] [-cn] inputfile[.root]" << endl << endl;
+    gLog << "     input file:   Mars root file." << endl;
+    gLog << "     -a0: Do not use Ansii codes." << endl;
+    gLog << "     -vn: Verbosity level n [default=2]" << endl << endl;
+}
 
 
 int main(int argc, char **argv)
 {
+    StartUpMessage();
+
+    //
+    // Evaluate arguments
+    //
+    MArgs arg(argc, (const char**)argv);
+
+    //
+    // Set verbosity to highest level.
+    //
+    gLog.SetDebugLevel(arg.HasOption("-v") ? arg.GetIntAndRemove("-v") : 2);
+
+    if (arg.HasOption("-a") && arg.GetIntAndRemove("-a")==0)
+        gLog.SetNoColors();
+
+    //
+    // check for the right usage of the program
+    //
+    if (arg.GetNumArguments()!=1)
+    {
+        Usage();
+        return -1;
+    }
+
+    //
+    // This is to make argv[i] more readable insidethe code
+    //
+    TString kNamein = arg.GetArgumentStr(0);
+
+    if (!kNamein.EndsWith(".root"))
+        kNamein += ".root";
+
+    //
+    // check whether the given files are OK.
+    //
+    if (gSystem->AccessPathName(kNamein, kFileExists))
+    {
+        gLog << err << "Sorry, the input file '" << kNamein << "' doesn't exist." << endl;
+        return -1;
+    }
+
     TApplication app("Status", &argc, argv);
-
+    if (gROOT->IsBatch() || !gClient)
+    {
+        gLog << "Bombing... maybe your DISPLAY variable is not set correctly!" << endl;
+        return 1;
+    }
+
+    MArray::Class()->IgnoreTObjectStreamer();
+    MParContainer::Class()->IgnoreTObjectStreamer();
 
     //
@@ -93,14 +172,14 @@
     //
     MReadMarsFile read("Events");
-    read.DisableAutoScheme();
+    //read.DisableAutoScheme();
 
     // ------------- user change -----------------
-    read.AddFile("/home/tbretz/cosmics.root");
+    read.AddFile(kNamein);
 
     MGeomApply        geomapl;
-
     MMcPedestalCopy   pcopy;
     MMcPedestalNSBAdd pnsb;
-    MCerPhotAnal2     ncalc;
+    MCerPhotCalc      ncalc;
+//    MCerPhotAnal2     ncalc;
 /*
     TArrayS blinds(6);
@@ -111,23 +190,23 @@
     blinds[4] = 271;
     blinds[5] = 291;
-    /*
+
      blinds[3] =  51;
      blinds[4] =  56;
-     blinds[5] = 112;//*
-     blinds[6] =  31;//*
+     blinds[5] = 112;
+     blinds[6] =  31;
      blinds[7] = 116;
      blinds[8] = 507;
      blinds[9] = 559;
-     blinds[10]= 291; // 311, 119, 54, 85, 125, 92, 133, 224*/
-/*
+     blinds[10]= 291; // 311, 119, 54, 85, 125, 92, 133, 224
+
     MBlindPixelCalc blind;
     blind.SetPixelIndices(blinds);
     //blind.SetUseInterpolation();
 */
-    MSigmabarCalc     sgcal;
+    // MSigmabarCalc     sgcal;
     MImgCleanStd      clean;
     MHillasCalc       hcalc;
     MHillasSrcCalc    scalc; // !!Preliminary!! Will be removed later!
-    MCT1SupercutsCalc calc1;
+    // MCT1SupercutsCalc calc1;
 
     MHCamEvent hist("PedestalRms");
@@ -144,9 +223,9 @@
     MFillH hfill6("MHHillasSrc","MHillasSrc");
     MFillH hfill7("MHNewImagePar","MNewImagePar");
-    MFillH hfill8a("MHStarMap", "MHillas");
-    MFillH hfill8b("MHStarMap2", "MHillas");
+    //MFillH hfill8a("MHStarMap", "MHillas");
+    //MFillH hfill8b("MHStarMap2", "MHillas");
     MFillH hfill9("Cleaned [MHCamEvent]", "MCerPhotEvt");
-    MFillH hfill10("MHHadronness", "MHadronness");
-    MFillH hfill11("MHSigmaTheta");
+    //MFillH hfill10("MHHadronness", "MHadronness");
+    //MFillH hfill11("MHSigmaTheta");
 
     tlist.AddToList(&read);
@@ -173,4 +252,5 @@
     tlist.AddToList(&hfill9);
     //tlist.AddToList(&hfill10);
+    //tlist.AddToList(&hfill11);
 
     MEvtLoop evtloop;
@@ -185,5 +265,4 @@
 
     tlist.PrintStatistics();
-
     return 0;
 }
@@ -27,10 +27,13 @@
 //  Status - Example how to use the MStatusDisplay
 //
-//  Use a camera file as input
+//  Use a camera file as input ----- PRELIMINARY
 //
 /////////////////////////////////////////////////////////////////////////////
